@@ -75,25 +75,6 @@ sub remove_job {
   return !!$self->jobs->remove($doc)->{n};
 }
 
-sub repair {
-  my $self = shift;
-
-  # Check workers on this host (all should be owned by the same user)
-  my $workers = $self->workers;
-  my $cursor = $workers->find({host => hostname});
-  while (my $worker = $cursor->next) {
-    $workers->remove({_id => $worker->{_id}}) unless kill 0, $worker->{pid};
-  }
-
-  # Abandoned jobs
-  my $jobs = $self->jobs;
-  $cursor = $jobs->find({state => 'active'});
-  while (my $job = $cursor->next) {
-    $jobs->save({%$job, state => 'failed', error => 'Worker went away.'})
-      unless $workers->find_one($job->{worker});
-  }
-}
-
 sub reset { $_->options && $_->drop for $_[0]->workers, $_[0]->jobs }
 
 sub restart_job {
@@ -196,7 +177,7 @@ Minion::Backend::Mango - MongoDB backend
 
 =head1 DESCRIPTION
 
-L<Minion::Backend::Mango> is a L<Mango> backend for L<Minion>.
+L<Minion::Backend::Mango> is a highly scalable L<Mango> backend for L<Minion>.
 
 =head1 ATTRIBUTES
 
@@ -309,12 +290,6 @@ Register worker.
 
 Remove C<failed>, C<finished> or C<inactive> job from queue.
 
-=head2 repair
-
-  $backend->repair;
-
-Repair worker registry and job queue.
-
 =head2 reset
 
   $backend->reset;
